import { JetStreamClient, JetStreamManager, ObjectInfo, ObjectResult, ObjectStore, ObjectStoreMeta, ObjectStoreMetaOptions, ObjectStoreOptions, ObjectStorePutOpts, ObjectStoreStatus, PubAck, PurgeResponse, StorageType, StreamInfo, StreamInfoRequestOptions } from "./types";
import { QueuedIterator } from "./queued_iterator";
export declare const osPrefix = "OBJ_";
export declare const digestType = "SHA-256=";
export declare function objectStoreStreamName(bucket: string): string;
export declare function objectStoreBucketName(stream: string): string;
export declare class ObjectStoreStatusImpl implements ObjectStoreStatus {
    si: StreamInfo;
    backingStore: string;
    constructor(si: StreamInfo);
    get bucket(): string;
    get description(): string;
    get ttl(): number;
    get storage(): StorageType;
    get replicas(): number;
    get sealed(): boolean;
    get size(): number;
    get streamInfo(): StreamInfo;
}
type ServerObjectStoreMeta = {
    name: string;
    description?: string;
    headers?: Record<string, string[]>;
    options?: ObjectStoreMetaOptions;
};
type ServerObjectInfo = {
    bucket: string;
    nuid: string;
    size: number;
    chunks: number;
    digest: string;
    deleted?: boolean;
    mtime: string;
} & ServerObjectStoreMeta;
export declare class ObjectStoreImpl implements ObjectStore {
    jsm: JetStreamManager;
    js: JetStreamClient;
    stream: string;
    name: string;
    constructor(name: string, jsm: JetStreamManager, js: JetStreamClient);
    _sanitizeName(name: string): {
        name: string;
        error?: Error;
    };
    info(name: string): Promise<ObjectInfo | null>;
    list(): Promise<ObjectInfo[]>;
    rawInfo(name: string): Promise<ServerObjectInfo | null>;
    _si(opts?: Partial<StreamInfoRequestOptions>): Promise<StreamInfo | null>;
    seal(): Promise<ObjectStoreStatus>;
    status(opts?: Partial<StreamInfoRequestOptions>): Promise<ObjectStoreStatus>;
    destroy(): Promise<boolean>;
    _put(meta: ObjectStoreMeta, rs: ReadableStream<Uint8Array> | null, opts?: ObjectStorePutOpts): Promise<ObjectInfo>;
    put(meta: ObjectStoreMeta, rs: ReadableStream<Uint8Array> | null, opts?: ObjectStorePutOpts): Promise<ObjectInfo>;
    get(name: string): Promise<ObjectResult | null>;
    linkStore(name: string, bucket: ObjectStore): Promise<ObjectInfo>;
    link(name: string, info: ObjectInfo): Promise<ObjectInfo>;
    delete(name: string): Promise<PurgeResponse>;
    update(name: string, meta?: Partial<ObjectStoreMeta>): Promise<PubAck>;
    watch(opts?: Partial<{
        ignoreDeletes?: boolean;
        includeHistory?: boolean;
    }>): Promise<QueuedIterator<ObjectInfo | null>>;
    _chunkSubject(id: string): string;
    _metaSubject(n: string): string;
    _metaSubjectAll(): string;
    init(opts?: Partial<ObjectStoreOptions>): Promise<void>;
    static create(js: JetStreamClient, name: string, opts?: Partial<ObjectStoreOptions>): Promise<ObjectStore>;
}
export {};
